using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net;
using System.Web;
using WebDAVSharp.Server.Adapters;
using WebDAVSharp.Server.Exceptions;
using WebDAVSharp.Server.Stores;

namespace WebDAVSharp.Server.MethodHandlers {
	/// <summary>
	/// This class implements the <c>MKCOL</c> HTTP method for WebDAV#.
	/// </summary>
	internal class WebDavMkColMethodHandler : WebDavMethodHandlerBase, IWebDavMethodHandler {
		/// <summary>
		/// Gets the collection of the names of the HTTP methods handled by this instance.
		/// </summary>
		/// <value>
		/// The names.
		/// </value>
		public IEnumerable<string> Names {
			get {
				return new[]
				{
										"MKCOL"
								};
			}
		}

		/// <summary>
		/// Processes the request.
		/// </summary>
		/// <param name="server">The <see cref="WebDavServer" /> through which the request came in from the client.</param>
		/// <param name="context">The 
		/// <see cref="IHttpListenerContext" /> object containing both the request and response
		/// objects to use.</param>
		/// <param name="store">The <see cref="IWebDavStore" /> that the <see cref="WebDavServer" /> is hosting.</param>
		/// <exception cref="WebDAVSharp.Server.Exceptions.WebDavUnsupportedMediaTypeException"></exception>
		/// <exception cref="WebDAVSharp.Server.Exceptions.WebDavMethodNotAllowedException"></exception>
		public void ProcessRequest(WebDavServer server, HttpContext context, IWebDavStore store, String fileName) {
			//if (context.Request.ContentLength64 > 0)
			//    throw new WebDavUnsupportedMediaTypeException();

			IWebDavStoreCollection collection = GetParentCollection(server, store, fileName);

			string collectionName = ExtractCollectionName(fileName);
			if (collection.GetItemByName(collectionName) != null)
				throw new WebDavMethodNotAllowedException();

			collection.CreateCollection(collectionName);

			context.SendSimpleResponse(HttpStatusCode.Created);
		}

		private string ExtractCollectionName(string fileName) {
			//segments.last.trim(/ \)
			return fileName.Split(new[] { '/', '\\' }, StringSplitOptions.RemoveEmptyEntries).Last();
		}
	}
}